@@ -66,11 +66,19 @@ class ServiceManager(object):
     '''
     The ServiceManager is intended to encapsulate all of the Google services for a user. The SM object must be tied to the registered OAUTH secret file, which the user must download from the Google Developer Console (https://console.developers.google.com/apis/credentials). The filename from Google will be "client_secret_{ids}.json", but the ServiceManager default looks for "google_client.json" in the "credentials" directory, but these can be overriden.
 
+    Public Class Properties:
+        api_key (str|None): The Google api key credential if you are uathenticating this way
+        oauth_unattended (bool): If this is an unattended script (and should not prompt for authentication), set this to True
+        oauth_secret_file: The filename or path of the secret file downloaded from the Google Credential page for OAuth
+        oauth_credential_directory: There directory where authentication should happen.
+
+
     Notes:
         Services are cached so that a reference to a Sheets service from two different parts of an application refer to the same service and service manager. In most cases, it ends up functioning like a singleton as only one user is likely to be authenticating to Google for a given script. But since there are plenty of potential needs to reference multiple paths, it can be explicitly instantiated to two different paths.
     '''
     api_key=None
-    oauth_secret_file = 'google_client.json'
+    oauth_unattended=False
+    oauth_secret_file='google_client.json'
     oauth_credential_directory='credentials'
     oauth_args = []
 
@@ -241,8 +249,25 @@ class ServiceManager(object):
                 oauth_secret_path,
                 permission_scope
             )
-            #if flags:
-            #    credentials = oauth2client.tools.run_flow(flow, store, flags)
-            #else:
-            credentials = oauth2client.tools.run_flow(flow, store)
+            # for whatever weird reason, ouath2client.tools requires command line arguments
+            # and will custom parse them if not provided.  So we have to mock them.  From the docs:
+            '''
+        ``--auth_host_name`` (string, default: ``localhost``)
+           Host name to use when running a local web server to handle
+           redirects during OAuth authorization.
+
+        ``--auth_host_port`` (integer, default: ``[8080, 8090]``)
+           Port to use when running a local web server to handle redirects
+           during OAuth authorization. Repeat this option to specify a list
+           of values.
+
+        ``--[no]auth_local_webserver`` (boolean, default: ``True``)
+           Run a local web server to handle redirects during OAuth
+           authorization.
+            '''
+
+            flags= oauth2client.tools.argparser.parse_args({})
+            if self.oauth_unattended:
+                raise PermissionError(f"A googleapps was called while running in an unattended mode. Credentials required for {local_credential_file} - {permission_scope}, but no valid credentials found. Please run this or another command manually to grant access permissions.")
+            credentials = oauth2client.tools.run_flow(flow, store, flags=flags)
         return(credentials)
